# 1.1
- Add format_name, format_slug, title_conservatively
- Update normalize_key to treat every non-character as a word separator
- Update normalize_key to allow custom text processing via process_text

# 1.0
- Restore compact_whitespace, normalize_key, unicode_safely
